--[[
|--------------------------------------|
|Finally,-some-metal-recycling!-╰(▔∀▔)╯|
|------coded by Monohive and Jul-------|
|--------------------------------------|
--]]

require("reMetals_core")

---@param success_status string
function reMetals.recipes.GetMaterialsBySuccessStatus(item_type, success_status)
	local materials_list = {}
	if success_status == "grand_success" then success_status = "success" end
	for key, _ in pairs(reMetals.recipes.parts_materials_by_name_list) do
		if string.find(item_type, key, 1, true) then
			materials_list = reMetals.recipes.parts_materials_by_name_list[key][success_status]
			return materials_list
		end
	end
end

function reMetals.recipes.AddMaterialsToInventory(player, items, success_status)
	if success_status == "grand_success" then player:getInventory():AddItems(items[1].name, items[1].max + 2)
	elseif #items > 1 then
		local how_many_materials = ZombRand(1, #items + 1)
		for i = 1, how_many_materials do
			player:getInventory():AddItems(items[i].name, ZombRand(1, (items[i].max + 1)))
		end
	else
		player:getInventory():AddItems(items[1].name, ZombRand(1, (items[1].max + 1)))
	end
end

function reMetals.recipes.AddXpBySuccessStatus(player, success_status)
	player:getXp():AddXP(Perks.MetalWelding, reMetals.recipes.xp_amount_for_recycling[success_status])
end


function reMetals.recipes.ManageResult(player, item_type, success_status)
	if success_status == "failed" then
		getPlayer():Say("I couldn't scrap anything usefull.")
		reMetals.recipes.AddXpBySuccessStatus(player, success_status)
	else
		reMetals.recipes.AddMaterialsToInventory(player, reMetals.recipes.GetMaterialsBySuccessStatus(item_type, success_status), success_status)
		reMetals.recipes.AddXpBySuccessStatus(player, success_status)
		reMetals.remembrance.SetMemory(player, item_type, reMetals.recipes.remembrance_chance_increment[success_status])
	end
end

function Recipe.OnGiveXP.MetalWelding5(recipe, ingredients, result, player)
	player:getXp():AddXP(Perks.MetalWelding, 5);
end

function Recipe.OnCreate.RecycleVehiclePart(items, result, player)
	local item_type = items:get(0):getType()
	local player_level = player:getPerkLevel(Perks.MetalWelding) == 0 and 1 or player:getPerkLevel(Perks.MetalWelding)
	local success_chance = player_level * 10
	local random_difficulty = ZombRand(0, 101)

	local player_item_memory = reMetals.remembrance.GetMemory(player, item_type)
	if player_item_memory then success_chance = success_chance + player_item_memory end
	local player_fatigue = player:getStats():getFatigue() * 10
	local fatigue_correction = 0
	if player_fatigue >= 7 then
    fatigue_correction = math.min((math.floor(player_fatigue) - 6) * 3, 10)
	end
	success_chance = math.min(success_chance, 100) - fatigue_correction

	local success_status
	if random_difficulty < success_chance then
		success_status = "success"
	elseif random_difficulty == success_chance then
		success_status = "grand_success"
	elseif random_difficulty > success_chance then
		if random_difficulty <= success_chance * 1.5 then
			success_status = 'partial_success'
		else
			success_status = 'failed'
		end
	end
	reMetals.recipes.ManageResult(player, item_type, success_status)
end

